@@ -1,6 +1,6 @@
 /*
  * IRiver ifp supporting functions, a basic (primative) API.
- * $Id: prim.c,v 1.26.2.1 2005/02/19 17:18:03 oakhamg Exp $
+ * $Id: prim.c,v 1.26.2.3 2005/08/21 23:38:28 oakhamg Exp $
  *
  * Copyright (C) Geoff Oakham, 2004; <oakhamg@users.sourceforge.net>
  */
@@ -283,7 +283,7 @@ static inline int _ifp_push_unicode(struct ifp_device * dev, const char * s, int
 	//'buf' from being overrun.  (We can tell afterwards, but by
 	//then it's too late.)
 	
-	i = ifp_utf8_to_utf16(buf, IFP_BUFFER_SIZE, s, strlen(s)+1);
+	i = ifp_locale_to_utf16(buf, IFP_BUFFER_SIZE, s, strlen(s)+1);
 	ifp_err_jump(i, err, "character conversion failed");
 
 	i = ifp_os_push(dev, buf, blocksize);
@@ -312,14 +312,14 @@ static inline int _ifp_pop_unicode(struct ifp_device * dev, char * s, int n,
 		}
 		return i;
 	}
-	i = ifp_utf16_to_utf8(s, n, buf, IFP_BUFFER_SIZE);
+	i = ifp_utf16_to_locale(s, n, buf, IFP_BUFFER_SIZE);
 	ifp_err_jump(i, err, "character conversion failed");
 err:
 #ifdef IFP_DEBUG_USB_SNOOPING
 	ifp_print("-->up '%s'[unicode]\n", s);
 #endif // IFP_DEBUG_USB_SNOOPING
 
-	return 0;
+	return i;
 }
 
 #if 0
