@@ -1,6 +1,6 @@
 /* 
  * IRiver ifp supporting functions, a basic (primative) API.
- * $Id: userfile.c,v 1.18.2.1 2005/01/25 01:49:11 oakhamg Exp $
+ * $Id: userfile.c,v 1.18.2.2 2005/08/22 03:03:56 oakhamg Exp $
  *
  * Copyright (C) Geoff Oakham, 2004; <oakhamg@users.sourceforge.net>
  */
@@ -947,7 +947,7 @@ err_0:
 	return i;
 }
 
-int file_compare_fts(const FTSENT **p1, const FTSENT **p2)
+int file_compare_fts(const FTSENT * const*p1, const FTSENT * const*p2)
 {
 	if (p1 == NULL) { ifp_err("p1 shouldn't be NULL"); return 0; }
 	if (p2 == NULL) { ifp_err("p2 shouldn't be NULL"); return 0; }
